| geom_bezier | R Documentation |
Draw grouped cubic Bezier paths from four control points per group.
geom_bezier(
mapping = NULL,
data = NULL,
n = 100,
stat = "identity",
position = "identity",
na.rm = FALSE,
show.legend = NA,
inherit.aes = FALSE,
...
)
mapping |
Set of aesthetic mappings created by |
data |
A data frame containing |
n |
Number of points sampled along each Bezier path. |
stat |
The statistical transformation used to process the layer data. |
position |
Position adjustment used to avoid overplotting. |
na.rm |
If |
show.legend |
Whether this layer should be drawn in the legends. |
inherit.aes |
Whether to inherit the aesthetic mappings of the plot.
Defaults to |
... |
Additional parameters passed to the layer. |
library(ggplot2)
edges <- data.frame(
x = c(0, 0.4, 1.6, 2),
y = c(0, 1.2, 1.2, 0),
group = 1
)
ggplot() + geom_bezier(aes(x, y, group = group), data = edges)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.